<?php

/**
 * An example of a project-specific implementation.
 *
 * After registering this autoload function with SPL, the following line
 * would cause the function to attempt to load the \Foo\Bar\Baz\Qux class
 * from /path/to/project/src/Baz/Qux.php:
 *
 *      new \Foo\Bar\Baz\Qux;
 *
 * @param string $class The fully-qualified class name.
 * @return void
 */
spl_autoload_register(function ($className) {

	// project-specific namespace prefix
	$prefix = 'BrewPixel\\BrewPress\\';

	// base directory for the namespace prefix
	$directories = array(
		'brewpress\\app\\Activation\\'  => realpath(__DIR__ . '/../app/Activation/'),
		'brewpress\\app\\Admin\\'  => realpath(__DIR__ . '/../app/Admin/'),
		'brewpress\\app\\AdminSetting\\'  => realpath(__DIR__ . '/../app/AdminSetting/'),
		'brewpress\\app\\BrewPixel\\'  => realpath(__DIR__ . '/../app/BrewPixel/'),
		'brewpress\\app\\CustomPostType\\'  => realpath(__DIR__ . '/../app/CustomPostType/'),
		'brewpress\\app\\Front\\'  => realpath(__DIR__ . '/../app/Front/'),
		'brewpress\\app\\Internationalisation\\'  => realpath(__DIR__ . '/../app/Internationalisation/'),
		'brewpress\\app\\Loader\\'  => realpath(__DIR__ . '/../app/Loader/'),
		'brewpress\\app\\MetaBox\\'  => realpath(__DIR__ . '/../app/MetaBox/'),
		'brewpress\\app\\Shortcode\\'  => realpath(__DIR__ . '/../app/Shortcode/'),
		'brewpress\\app\\'  => realpath(__DIR__ . '/../app/')
	);
	foreach ($directories as $namespace => $directory) {
		// Check if the called class is part of this namespace
		if ( strpos( $className, $namespace ) !== 0 ) {
			continue;
		}

		// Strip the namespace from the class name (Enables PSR-4)
		$className = str_replace( $namespace, '', $className );

		// Build the path to the supposed class file
		$className = str_replace( '\\', '/', $className );
		$filename  = rtrim( $directory, '/' ) . '/' . $className . '.php';

		if ( ! file_exists( $filename ) ) {
			continue;
		}

		include_once $filename;
	}
});